@@ -1,8 +1,9 @@
 class Attribute:
-    def __init__(self, key, value, dom):
+    def __init__(self, key, value, dom, twoWay=False):
         self.key = key
         self.value = value
         self.dom = dom
+        self.twoWay = twoWay
 
     def toDict(self):
         return {self.key: self.value}
\ No newline at end of file
