@@ -50,7 +50,7 @@ class Observable(ObservableBase):
 
     @value.setter
     def value(self, v):
-        if v is self._value:
+        if v == self._value:
             return
         self._value = v
         # [v['func'](self._value) for v in self.changeActionsList]
@@ -81,7 +81,7 @@ class Computed(ObservableBase):
 
     @value.setter
     def value(self, v):
-        if v is self._value:
+        if v == self._value:
             return
         self._value = v
         # [v['func'](self._value) for v in self.changeActionsList]
