@@ -13,12 +13,12 @@ size = {
     'minWidth': ['setMinimumWidth', int],
     'width': ['setFixedWidth', int],
     'height': ['setFixedHeight', int],
-    'visible': ['setVisible', bool]
+    'visible': ['setVisible', [int, bool]]
 }
 
 common = {
     'text': ['setText', str],
-    'enable': ['setEnabled', bool]
+    'enable': ['setEnabled', [int, bool]]
 }
 
 align = {
@@ -27,19 +27,24 @@ align = {
 
 btn = {
     'checked': ['setChecked', [int, bool]],
-    'checkable': ['setCheckable', bool]
+    'checkable': ['setCheckable', [int, bool]]
+}
+
+style = {
+    'qss': ['setStyleSheet', [str, t.readFile]],
+    'style': [f.setStyleSheet, str]
 }
 
 ElementAttr = {
     'widget': {
         **size,
-        'style': ['setStyleSheet', [str, t.readFile]],
+        **style,
         'title': ['setWindowTitle', str],
         'pos': ['move', t.toList(int)],
         'full': ['showType', [int, bool]]
     },
     'frame': {
-        **size,
+        **size, **style,
         'shape': ['setFrameShape', t.frameShape],
         'shadow': ['setFrameShadow', t.frameShadow],
         'linew': ['setLineWidth', int],
@@ -55,7 +60,7 @@ ElementAttr = {
         'checked': [f.groupChecked, None]
     },
     'button': {
-        **size, **common, **btn,
+        **size, **common, **btn, **style,
         'shortcut': ['setShortcut', str],
         'tooltip': ['setToolTip', str],
         'icon': ['setIcon', str],
@@ -64,27 +69,44 @@ ElementAttr = {
         'repeatInterval': ['setAutoRepeatInterval', int]
     },
     'radio': {
-        **common, **btn
+        **common, **btn, **style
     },
     'label': {
-        **size, **common, **align,
+        **size, **common, **align, **style,
         'cv': ['setTextOrPixmap', t.cvImg],
         'cvPath': ['setPixmap', [str, t.cvPathImg]],
         'scaledContents': ['setScaledContents', [int, bool]]
     },
     'tab': {
+        **style,
         'pos': ['setTabPosition', t.tabPosition],
         'name': ['setTabText', t.toList([int, str])]
     },
     'status': {
+        **style,
         'msg': ['showMessage', str]
     },
     'select': {
-        'index': ['setCurrentIndex', int]
+        **style,
+        'index': [f.indexChanged, None]
     },
     'text-edit': {
+        **style,
         'text': [f.textChanged, None],
         'html': [f.htmlChanged, None]
+    },
+    'menu': {
+        **style,
+        'title': ['setTitle', str]
+    },
+    'action': {
+        **style,
+        'text': ['setText', str],
+        'tooltip': ['setToolTip', str],
+        'shortcut': ['setShortcut', str],
+        'enable': ['setEnabled', [int, bool]],
+        'checked': ['setChecked', [int, bool]],
+        'checkable': ['setCheckable', [int, bool]]
     }
 }
 
