@@ -7,8 +7,12 @@ class Widget(QWidget):
         else:
             return super().show()
 
-class Window(QMainWindow, Widget):
-    pass
+class Window(QMainWindow):
+    def showType(self, isFull):
+        if isFull:
+            return super().showFullScreen()
+        else:
+            return super().show()
 
 class Label(QLabel):
     def setTextOrPixmap(self, data):
